# gera2ld.aioproxy

[![PyPI](https://img.shields.io/pypi/v/gera2ld.aioproxy.svg)](https://pypi.org/project/gera2ld.aioproxy/)

A simple transparent proxy server implemented with pure Python.

Both HTTP proxy and SOCKS proxy are supported on the same port.

## Installation

```sh
$ pip3 install gera2ld.aioproxy
```

## Usage

```sh
$ aioproxy [-b :1086] [-x socks5://127.0.0.1:1080]
```
